@@ -11,10 +11,13 @@ from pagador.utils import Formatador
 class Enviar(object):
     def __init__(self, pedido, dados, configuracao_pagamento):
         self.pedido = pedido
+        self.conta_id = None
+        self.pedido_numero = None
+        if pedido:
+            self.conta_id = self.pedido.conta_id
+            self.pedido_numero = self.pedido.numero
         self.dados = dados
         self.configuracao_pagamento = configuracao_pagamento
-        self.conta_id = self.pedido.conta_id
-        self.pedido_numero = self.pedido.numero
 
     @property
     def formatador(self):
